Learn R Programming

RDIDQ (version 1.0)

didq_summry: Summary function

Description

This function gives a simple summary of the data

Usage

didq_summry(test)

Arguments

test
test: a dataset whose summary is to be obtained

Value

returns Data frame

Details

The function helps in better understanding of the dataset by giving the detailed summary of all the variables like thei class,unique values,missing percentage ,missing and non-missing value

References

http://en.wikipedia.org/wiki/Summary_statistic

See Also

sumry_categorical and sumry_continous

Examples

Run this code
data(iris)
sumry=didq_summry(iris)

Run the code above in your browser using DataLab