Learn R Programming

RDIDQ (version 1.0)

ident_cat: Categorical(Character) variable Identifier

Description

This function identifies Categorical variable from the main dataset and returns a dataset that has only categorical variables

Usage

ident_cat(test)

Arguments

test
test: dataset that has both categorical and continous variable

Value

it returns Data frame object

Details

This function identifies Categorical variable from the main dataset and returns a dataset that has only categorical variables

See Also

ident_cont for identifying continous variable

Examples

Run this code
data(iris)
cont_data=ident_cont(iris)

Run the code above in your browser using DataLab