RDIDQ-package:
Functions to perform Extrapolative data analysis
RDIDQ
Description
It provides many function that helps in performing quality check on the data and also give a very brief overview of the data sperately for both numeric and character type data
Arguments
Details
Package:
RDIDQ
Type:
Package
Version:
1.0
Date:
2012-12-08
License:
GPL-2
References
http://en.wikipedia.org/wiki/Data_analysis
See Also
ident_cont and ident_cat for identifying continous and categorical variable